# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineEngineClassPermission(Model):
    """BaselineEngineClassPermission.

    :param run:
    :type run: bool
    """

    _attribute_map = {
        'run': {'key': 'run', 'type': 'bool'},
    }

    def __init__(self, run=None):
        super(BaselineEngineClassPermission, self).__init__()
        self.run = run



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyStarRating(Model):
    """PlaceDigestEnergyStarRating.

    :param energy_star_rating_id: energy star history identifier
    :type energy_star_rating_id: int
    :param energy_star_submit_id: energy star submit history identifier
    :type energy_star_submit_id: int
    :param rating_date: rating date
    :type rating_date: datetime
    :param rating_month: month of rating
    :type rating_month: int
    :param rating_year: year of rating
    :type rating_year: int
    :param rating: rating value
    :type rating: int
    :param note: note about the rating
    :type note: str
    :param kbtu_total_wn: kbtu total weather
    :type kbtu_total_wn: float
    :param kbtu_total_nwn: kbtu total non-weather
    :type kbtu_total_nwn: float
    :param kbtu_sfwn: kbtu square foot weather
    :type kbtu_sfwn: float
    :param kbtu_sfnwn: kbtu square foot non weather
    :type kbtu_sfnwn: float
    :param source_kbtu_total_wn: source kbtu total weather
    :type source_kbtu_total_wn: float
    :param source_kbtu_total_nwn: source kbtu total non-weather
    :type source_kbtu_total_nwn: float
    :param source_kbtu_sfwn: source kbtu square foot weather
    :type source_kbtu_sfwn: float
    :param source_kbtu_sfnwn: source kbtu square foot non-weather
    :type source_kbtu_sfnwn: float
    :param kbtu_sf_score_of50: kbtu square foot score of 50
    :type kbtu_sf_score_of50: float
    :param kbtu_sf_score_of75: kbtu square foot score of 75
    :type kbtu_sf_score_of75: float
    :param lbs_co2_emissions: CO2 emissions in pounds
    :type lbs_co2_emissions: float
    :param direct_ghg_emissions: direct GHG emissions
    :type direct_ghg_emissions: float
    :param indirect_ghg_emissions: indirect GHG emissions
    :type indirect_ghg_emissions: float
    :param total_ghg_emissions: total GHG emissions
    :type total_ghg_emissions: float
    :param apply_for_label_eligible: if place is eligible for label
    :type apply_for_label_eligible: bool
    :param rateable: if placetype of place is rateable
    :type rateable: bool
    """

    _attribute_map = {
        'energy_star_rating_id': {'key': 'energyStarRatingId', 'type': 'int'},
        'energy_star_submit_id': {'key': 'energyStarSubmitId', 'type': 'int'},
        'rating_date': {'key': 'ratingDate', 'type': 'iso-8601'},
        'rating_month': {'key': 'ratingMonth', 'type': 'int'},
        'rating_year': {'key': 'ratingYear', 'type': 'int'},
        'rating': {'key': 'rating', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
        'kbtu_total_wn': {'key': 'kbtuTotalWN', 'type': 'float'},
        'kbtu_total_nwn': {'key': 'kbtuTotalNWN', 'type': 'float'},
        'kbtu_sfwn': {'key': 'kbtuSFWN', 'type': 'float'},
        'kbtu_sfnwn': {'key': 'kbtuSFNWN', 'type': 'float'},
        'source_kbtu_total_wn': {'key': 'sourceKbtuTotalWN', 'type': 'float'},
        'source_kbtu_total_nwn': {'key': 'sourceKbtuTotalNWN', 'type': 'float'},
        'source_kbtu_sfwn': {'key': 'sourceKbtuSFWN', 'type': 'float'},
        'source_kbtu_sfnwn': {'key': 'sourceKbtuSFNWN', 'type': 'float'},
        'kbtu_sf_score_of50': {'key': 'kbtuSFScoreOf50', 'type': 'float'},
        'kbtu_sf_score_of75': {'key': 'kbtuSFScoreOf75', 'type': 'float'},
        'lbs_co2_emissions': {'key': 'lbsCO2Emissions', 'type': 'float'},
        'direct_ghg_emissions': {'key': 'directGhgEmissions', 'type': 'float'},
        'indirect_ghg_emissions': {'key': 'indirectGhgEmissions', 'type': 'float'},
        'total_ghg_emissions': {'key': 'totalGhgEmissions', 'type': 'float'},
        'apply_for_label_eligible': {'key': 'applyForLabelEligible', 'type': 'bool'},
        'rateable': {'key': 'rateable', 'type': 'bool'},
    }

    def __init__(self, energy_star_rating_id=None, energy_star_submit_id=None, rating_date=None, rating_month=None, rating_year=None, rating=None, note=None, kbtu_total_wn=None, kbtu_total_nwn=None, kbtu_sfwn=None, kbtu_sfnwn=None, source_kbtu_total_wn=None, source_kbtu_total_nwn=None, source_kbtu_sfwn=None, source_kbtu_sfnwn=None, kbtu_sf_score_of50=None, kbtu_sf_score_of75=None, lbs_co2_emissions=None, direct_ghg_emissions=None, indirect_ghg_emissions=None, total_ghg_emissions=None, apply_for_label_eligible=None, rateable=None):
        super(PlaceDigestEnergyStarRating, self).__init__()
        self.energy_star_rating_id = energy_star_rating_id
        self.energy_star_submit_id = energy_star_submit_id
        self.rating_date = rating_date
        self.rating_month = rating_month
        self.rating_year = rating_year
        self.rating = rating
        self.note = note
        self.kbtu_total_wn = kbtu_total_wn
        self.kbtu_total_nwn = kbtu_total_nwn
        self.kbtu_sfwn = kbtu_sfwn
        self.kbtu_sfnwn = kbtu_sfnwn
        self.source_kbtu_total_wn = source_kbtu_total_wn
        self.source_kbtu_total_nwn = source_kbtu_total_nwn
        self.source_kbtu_sfwn = source_kbtu_sfwn
        self.source_kbtu_sfnwn = source_kbtu_sfnwn
        self.kbtu_sf_score_of50 = kbtu_sf_score_of50
        self.kbtu_sf_score_of75 = kbtu_sf_score_of75
        self.lbs_co2_emissions = lbs_co2_emissions
        self.direct_ghg_emissions = direct_ghg_emissions
        self.indirect_ghg_emissions = indirect_ghg_emissions
        self.total_ghg_emissions = total_ghg_emissions
        self.apply_for_label_eligible = apply_for_label_eligible
        self.rateable = rateable



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowEdit(Model):
    """ChargebackWorkflowEdit.

    :param chargeback_workflow_info: Name given to the chargeback workflow
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type chargeback_workflow_info: str
    :param chargeback_workflow_steps: List of chargeback workflow steps with
     details
     Order of the steps in the list determines the steps in the workflow. <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type chargeback_workflow_steps:
     list[~energycap.sdk.models.ChargebackWorkflowStepEdit]
    """

    _validation = {
        'chargeback_workflow_info': {'required': True, 'max_length': 64, 'min_length': 0},
    }

    _attribute_map = {
        'chargeback_workflow_info': {'key': 'chargebackWorkflowInfo', 'type': 'str'},
        'chargeback_workflow_steps': {'key': 'chargebackWorkflowSteps', 'type': '[ChargebackWorkflowStepEdit]'},
    }

    def __init__(self, chargeback_workflow_info, chargeback_workflow_steps=None):
        super(ChargebackWorkflowEdit, self).__init__()
        self.chargeback_workflow_info = chargeback_workflow_info
        self.chargeback_workflow_steps = chargeback_workflow_steps



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FloorAreaSplit(Model):
    """FloorAreaSplit.

    :param destination_account_id: Destination account ID
     There must be an existing relationship between the DestinationAccountId
     and DestinationMeterId <span class='property-internal'>Required</span>
     <span class='property-internal'>Topmost (CostCenter)</span>
    :type destination_account_id: int
    :param destination_meter_id: Destination meter ID
     There must be an existing relationship between the DestinationAccountId
     and DestinationMeterId <span class='property-internal'>Required</span>
     <span class='property-internal'>Topmost (LogicalDevice)</span>
    :type destination_meter_id: int
    :param weighting_factor: Weighting factor to apply in floor area bill
     split for this account and meter <span class='property-info'>Max precision
     of 8</span> <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and
     1.7976931348623157E+308</span>
    :type weighting_factor: float
    """

    _validation = {
        'destination_account_id': {'required': True},
        'destination_meter_id': {'required': True},
        'weighting_factor': {'required': True, 'minimum': 0},
    }

    _attribute_map = {
        'destination_account_id': {'key': 'destinationAccountId', 'type': 'int'},
        'destination_meter_id': {'key': 'destinationMeterId', 'type': 'int'},
        'weighting_factor': {'key': 'weightingFactor', 'type': 'float'},
    }

    def __init__(self, destination_account_id, destination_meter_id, weighting_factor):
        super(FloorAreaSplit, self).__init__()
        self.destination_account_id = destination_account_id
        self.destination_meter_id = destination_meter_id
        self.weighting_factor = weighting_factor



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteMeterChannelLatestReadingResponse(Model):
    """RouteMeterChannelLatestReadingResponse.

    :param meters: List of meters with channels and their latest reading
    :type meters:
     list[~energycap.sdk.models.MeterChildIncludePlaceChannelLatestReading]
    :param route_id: The route identifier
    :type route_id: int
    :param route_info: The route info
    :type route_info: str
    :param route_code: The route code
    :type route_code: str
    """

    _attribute_map = {
        'meters': {'key': 'meters', 'type': '[MeterChildIncludePlaceChannelLatestReading]'},
        'route_id': {'key': 'routeId', 'type': 'int'},
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
    }

    def __init__(self, meters=None, route_id=None, route_info=None, route_code=None):
        super(RouteMeterChannelLatestReadingResponse, self).__init__()
        self.meters = meters
        self.route_id = route_id
        self.route_info = route_info
        self.route_code = route_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityMismatchChild(Model):
    """CommodityMismatchChild.

    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param count:
    :type count: int
    """

    _attribute_map = {
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'count': {'key': 'count', 'type': 'int'},
    }

    def __init__(self, commodity=None, count=None):
        super(CommodityMismatchChild, self).__init__()
        self.commodity = commodity
        self.count = count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagWidgetChild(Model):
    """FlagWidgetChild.

    :param item_id: Identifier for the item could be meterId, placeId,
     accountId
    :type item_id: int
    :param item_display: Item display (name or code)
    :type item_display: str
    :param item_type: If item is a meter, this will be commodityCode
     If item is a building, this will say BUILDING
     If item is a account, this will say ACCOUNT
    :type item_type: str
    :param parent_id: Identifier for the parent of the item could be placeId,
     costCenterId
    :type parent_id: int
    :param parent_display: Parent display (name or code)
    :type parent_display: str
    :param parent_item_type: If parent is a building, this will say BUILDING
     For all other types, it will say ORGANIZATION
     If parent is a costcenter, this will say COSTCENTER
    :type parent_item_type: str
    :param split_parent: If the view is by Account or Meter, true indicates
     the account or meter is a master for a "Bill split"
    :type split_parent: bool
    :param split_child: If the view is by Account or Meter, true indicates the
     account or meter is a recipient of a "Bill split"
    :type split_child: bool
    :param calculated: If the view is by Account or Meter, true indicates the
     account or meter is part of a "Bill calculation"
    :type calculated: bool
    :param active: If the view is by Account or Meter, true indicates the
     account or meter is active
    :type active: bool
    :param cost: Total cost of all the bills that have flags for this item
    :type cost: float
    :param cost_recovery: Total cost recovery for bill flags for this item
    :type cost_recovery: float
    :param flag_count: Total number of bill flags for this item
    :type flag_count: int
    """

    _attribute_map = {
        'item_id': {'key': 'itemId', 'type': 'int'},
        'item_display': {'key': 'itemDisplay', 'type': 'str'},
        'item_type': {'key': 'itemType', 'type': 'str'},
        'parent_id': {'key': 'parentId', 'type': 'int'},
        'parent_display': {'key': 'parentDisplay', 'type': 'str'},
        'parent_item_type': {'key': 'parentItemType', 'type': 'str'},
        'split_parent': {'key': 'splitParent', 'type': 'bool'},
        'split_child': {'key': 'splitChild', 'type': 'bool'},
        'calculated': {'key': 'calculated', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'cost': {'key': 'cost', 'type': 'float'},
        'cost_recovery': {'key': 'costRecovery', 'type': 'float'},
        'flag_count': {'key': 'flagCount', 'type': 'int'},
    }

    def __init__(self, item_id=None, item_display=None, item_type=None, parent_id=None, parent_display=None, parent_item_type=None, split_parent=None, split_child=None, calculated=None, active=None, cost=None, cost_recovery=None, flag_count=None):
        super(FlagWidgetChild, self).__init__()
        self.item_id = item_id
        self.item_display = item_display
        self.item_type = item_type
        self.parent_id = parent_id
        self.parent_display = parent_display
        self.parent_item_type = parent_item_type
        self.split_parent = split_parent
        self.split_child = split_child
        self.calculated = calculated
        self.active = active
        self.cost = cost
        self.cost_recovery = cost_recovery
        self.flag_count = flag_count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveBillsDestination(Model):
    """MoveBillsDestination.

    :param commodities:  <span class='property-internal'>Required
     (defined)</span>
    :type commodities: list[~energycap.sdk.models.CommodityChild]
    :param accounts:  <span class='property-internal'>Required
     (defined)</span>
    :type accounts: list[~energycap.sdk.models.DestinationAccountResponse]
    """

    _attribute_map = {
        'commodities': {'key': 'commodities', 'type': '[CommodityChild]'},
        'accounts': {'key': 'accounts', 'type': '[DestinationAccountResponse]'},
    }

    def __init__(self, commodities=None, accounts=None):
        super(MoveBillsDestination, self).__init__()
        self.commodities = commodities
        self.accounts = accounts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculateSavingsRequest(Model):
    """CalculateSavingsRequest.

    :param bill_selection_option: Determines which option will be used to
     select the bills for this instance of the cost avoidance processor to
     process
     - "AllBills" means all bills will be processed
     - "ModifiedOrNotProcessed" means only new bills or bills which have been
     modified since the last time cost avoidance was run will be processed
     - "BillingPeriod" means that only bills with a billing period which is
     greater than or equal to the provided billing period will be processed
     <span class='property-internal'>One of AllBills, ModifiedOrNotProcessed,
     BillingPeriod </span>
    :type bill_selection_option: str
    :param billing_period: When BillSelectionOption is 'BillingPeriod', this
     defines the billing period to be used to target bills for processing <span
     class='property-internal'>Required when BillSelectionOption is set to
     BillingPeriod</span>
    :type billing_period: int
    :param skip_special_adjustment_option: Allow the user to optionally
     exclude one or all special adjustments <span class='property-internal'>One
     of SkipAll, SkipOne, SkipNone </span>
    :type skip_special_adjustment_option: str
    :param special_adjustment_type_id_to_ignore: During cost avoidance
     processing, the special adjustment having the provided special adjustment
     type ID will not be applied (only if SkipSpecialAdjustmentOption =
     "SkipOne") <span class='property-internal'>Required when
     SkipSpecialAdjustmentOption is set to SkipOne</span>
    :type special_adjustment_type_id_to_ignore: int
    :param filters: Filter criteria which determine the meters whose savings
     will be reprocessed
    :type filters: list[~energycap.sdk.models.FilterEdit]
    """

    _attribute_map = {
        'bill_selection_option': {'key': 'billSelectionOption', 'type': 'str'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'skip_special_adjustment_option': {'key': 'skipSpecialAdjustmentOption', 'type': 'str'},
        'special_adjustment_type_id_to_ignore': {'key': 'specialAdjustmentTypeIdToIgnore', 'type': 'int'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
    }

    def __init__(self, bill_selection_option=None, billing_period=None, skip_special_adjustment_option=None, special_adjustment_type_id_to_ignore=None, filters=None):
        super(CalculateSavingsRequest, self).__init__()
        self.bill_selection_option = bill_selection_option
        self.billing_period = billing_period
        self.skip_special_adjustment_option = skip_special_adjustment_option
        self.special_adjustment_type_id_to_ignore = special_adjustment_type_id_to_ignore
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestActualAndCalendarizedYearlyResponse(Model):
    """PlaceDigestActualAndCalendarizedYearlyResponse.

    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_id: The place identifier
    :type place_id: int
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestActualAndCalendarizedYearlyResponseResults]
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.PlaceDigestActualAndCalendarizedYearlyResponseCommodityData]
    """

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestActualAndCalendarizedYearlyResponseResults]'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[PlaceDigestActualAndCalendarizedYearlyResponseCommodityData]'},
    }

    def __init__(self, place_code=None, place_info=None, place_id=None, target_comparison=None, results=None, updated=None, global_use_unit=None, cost_unit=None, commodities=None):
        super(PlaceDigestActualAndCalendarizedYearlyResponse, self).__init__()
        self.place_code = place_code
        self.place_info = place_info
        self.place_id = place_id
        self.target_comparison = target_comparison
        self.results = results
        self.updated = updated
        self.global_use_unit = global_use_unit
        self.cost_unit = cost_unit
        self.commodities = commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeneralLedgerChild(Model):
    """GeneralLedgerChild.

    :param general_ledger_id:
    :type general_ledger_id: int
    :param general_ledger_code:
    :type general_ledger_code: str
    :param general_ledger_info:
    :type general_ledger_info: str
    """

    _attribute_map = {
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'general_ledger_info': {'key': 'generalLedgerInfo', 'type': 'str'},
    }

    def __init__(self, general_ledger_id=None, general_ledger_code=None, general_ledger_info=None):
        super(GeneralLedgerChild, self).__init__()
        self.general_ledger_id = general_ledger_id
        self.general_ledger_code = general_ledger_code
        self.general_ledger_info = general_ledger_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupDigestWeatherRankingResponse(Model):
    """PlaceGroupDigestWeatherRankingResponse.

    :param high_weather_load:
    :type high_weather_load: float
    :param low_weather_load:
    :type low_weather_load: float
    :param average_weather_load:
    :type average_weather_load: float
    :param median_weather_load:
    :type median_weather_load: float
    :param high_non_weather_load:
    :type high_non_weather_load: float
    :param low_non_weather_load:
    :type low_non_weather_load: float
    :param average_non_weather_load:
    :type average_non_weather_load: float
    :param median_non_weather_load:
    :type median_non_weather_load: float
    :param results:
    :type results:
     list[~energycap.sdk.models.PlaceGroupDigestWeatherRankingChild]
    :param place_group_id:
    :type place_group_id: int
    :param place_group_code:
    :type place_group_code: str
    :param place_group_info:
    :type place_group_info: str
    :param place_group_display: This is the user's preferred way of viewing
     this entity - could be code or info based on the master "data object view"
     setting in DB
    :type place_group_display: str
    :param benchmark_unit: This will provide the benchmark unit eg:MMBTU/ft²
     or $/day
    :type benchmark_unit: str
    :param benchmark_factor_unit: This will provide the unit for the
     benchmarking factor eg:ft² or day
    :type benchmark_factor_unit: str
    :param benchmark_value_unit: This will provide the unit for the benchmark
     value eg:$ for cost/day, MMBTU for annualized use/area
    :type benchmark_value_unit: str
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    """

    _attribute_map = {
        'high_weather_load': {'key': 'highWeatherLoad', 'type': 'float'},
        'low_weather_load': {'key': 'lowWeatherLoad', 'type': 'float'},
        'average_weather_load': {'key': 'averageWeatherLoad', 'type': 'float'},
        'median_weather_load': {'key': 'medianWeatherLoad', 'type': 'float'},
        'high_non_weather_load': {'key': 'highNonWeatherLoad', 'type': 'float'},
        'low_non_weather_load': {'key': 'lowNonWeatherLoad', 'type': 'float'},
        'average_non_weather_load': {'key': 'averageNonWeatherLoad', 'type': 'float'},
        'median_non_weather_load': {'key': 'medianNonWeatherLoad', 'type': 'float'},
        'results': {'key': 'results', 'type': '[PlaceGroupDigestWeatherRankingChild]'},
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'place_group_code': {'key': 'placeGroupCode', 'type': 'str'},
        'place_group_info': {'key': 'placeGroupInfo', 'type': 'str'},
        'place_group_display': {'key': 'placeGroupDisplay', 'type': 'str'},
        'benchmark_unit': {'key': 'benchmarkUnit', 'type': 'str'},
        'benchmark_factor_unit': {'key': 'benchmarkFactorUnit', 'type': 'str'},
        'benchmark_value_unit': {'key': 'benchmarkValueUnit', 'type': 'str'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, high_weather_load=None, low_weather_load=None, average_weather_load=None, median_weather_load=None, high_non_weather_load=None, low_non_weather_load=None, average_non_weather_load=None, median_non_weather_load=None, results=None, place_group_id=None, place_group_code=None, place_group_info=None, place_group_display=None, benchmark_unit=None, benchmark_factor_unit=None, benchmark_value_unit=None, use_unit=None, cost_unit=None, updated=None):
        super(PlaceGroupDigestWeatherRankingResponse, self).__init__()
        self.high_weather_load = high_weather_load
        self.low_weather_load = low_weather_load
        self.average_weather_load = average_weather_load
        self.median_weather_load = median_weather_load
        self.high_non_weather_load = high_non_weather_load
        self.low_non_weather_load = low_non_weather_load
        self.average_non_weather_load = average_non_weather_load
        self.median_non_weather_load = median_non_weather_load
        self.results = results
        self.place_group_id = place_group_id
        self.place_group_code = place_group_code
        self.place_group_info = place_group_info
        self.place_group_display = place_group_display
        self.benchmark_unit = benchmark_unit
        self.benchmark_factor_unit = benchmark_factor_unit
        self.benchmark_value_unit = benchmark_value_unit
        self.use_unit = use_unit
        self.cost_unit = cost_unit
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ShareRequest(Model):
    """ShareRequest.

    :param shared_with_everyone: Set to True to share the item everyone
     When true, SharedUsers and SharedUserGroups should be set to empty lists
     [] <span class='property-internal'>Required</span>
    :type shared_with_everyone: bool
    :param shared_user_ids: The list of individual user ids an item should be
     shared with
     Should be an empty list [], when SharedWithEveryone is true <span
     class='property-internal'>Required</span>
    :type shared_user_ids: list[int]
    :param shared_user_group_ids: The list of user group ids an item should be
     shared with
     Should be an empty list [], when SharedWithEveryone is true <span
     class='property-internal'>Required</span>
    :type shared_user_group_ids: list[int]
    """

    _validation = {
        'shared_with_everyone': {'required': True},
        'shared_user_ids': {'required': True},
        'shared_user_group_ids': {'required': True},
    }

    _attribute_map = {
        'shared_with_everyone': {'key': 'sharedWithEveryone', 'type': 'bool'},
        'shared_user_ids': {'key': 'sharedUserIds', 'type': '[int]'},
        'shared_user_group_ids': {'key': 'sharedUserGroupIds', 'type': '[int]'},
    }

    def __init__(self, shared_with_everyone, shared_user_ids, shared_user_group_ids):
        super(ShareRequest, self).__init__()
        self.shared_with_everyone = shared_with_everyone
        self.shared_user_ids = shared_user_ids
        self.shared_user_group_ids = shared_user_group_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillCreate(Model):
    """BillCreate.

    :param account_id: The bill's account <span
     class='property-internal'>Required</span>
    :type account_id: int
    :param begin_date: The bill's begin date <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type begin_date: datetime
    :param end_date: The bill's end date <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type end_date: datetime
    :param billing_period: The bill's billing period <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 190001 and 209912</span>
    :type billing_period: int
    :param account_period: The bill's accounting period
     Depending on your settings you can have up to 13 accounting periods <span
     class='property-internal'>Must be between 190001 and 209913</span>
    :type account_period: int
    :param estimated: Indicates if the bill is estimated
    :type estimated: bool
    :param manual_entry: The bill's entry method.  True = manual entry, false
     = automatic entry. <span class='property-internal'>Required</span>
    :type manual_entry: bool
    :param statement_date: The date and time of the bill statement <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type statement_date: datetime
    :param due_date: The date and time the bill is due <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type due_date: datetime
    :param next_reading: The date and time the of the next reading <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type next_reading: datetime
    :param control_code: The bill's control code <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type control_code: str
    :param invoice_number: The bill's invoice number <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type invoice_number: str
    :param note: The bill note
    :type note: str
    :param meters: The meters with line items
    :type meters: list[~energycap.sdk.models.BillMeterCreate]
    :param account_body_lines: The account line items
    :type account_body_lines:
     list[~energycap.sdk.models.BillAccountBodyLineCreate]
    """

    _validation = {
        'account_id': {'required': True},
        'begin_date': {'required': True},
        'end_date': {'required': True},
        'billing_period': {'required': True, 'maximum': 209912, 'minimum': 190001},
        'account_period': {'maximum': 209913, 'minimum': 190001},
        'manual_entry': {'required': True},
        'control_code': {'max_length': 255, 'min_length': 0},
        'invoice_number': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'account_period': {'key': 'accountPeriod', 'type': 'int'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'manual_entry': {'key': 'manualEntry', 'type': 'bool'},
        'statement_date': {'key': 'statementDate', 'type': 'iso-8601'},
        'due_date': {'key': 'dueDate', 'type': 'iso-8601'},
        'next_reading': {'key': 'nextReading', 'type': 'iso-8601'},
        'control_code': {'key': 'controlCode', 'type': 'str'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'meters': {'key': 'meters', 'type': '[BillMeterCreate]'},
        'account_body_lines': {'key': 'accountBodyLines', 'type': '[BillAccountBodyLineCreate]'},
    }

    def __init__(self, account_id, begin_date, end_date, billing_period, manual_entry, account_period=None, estimated=None, statement_date=None, due_date=None, next_reading=None, control_code=None, invoice_number=None, note=None, meters=None, account_body_lines=None):
        super(BillCreate, self).__init__()
        self.account_id = account_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.billing_period = billing_period
        self.account_period = account_period
        self.estimated = estimated
        self.manual_entry = manual_entry
        self.statement_date = statement_date
        self.due_date = due_date
        self.next_reading = next_reading
        self.control_code = control_code
        self.invoice_number = invoice_number
        self.note = note
        self.meters = meters
        self.account_body_lines = account_body_lines



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCalendarizedUseVsWeatherResponse(Model):
    """MeterCalendarizedUseVsWeatherResponse.

    :param year: The year
    :type year: int
    :param is_heating_weather_sensitive: Is heating weather sensitive?
    :type is_heating_weather_sensitive: bool
    :param winter_balance_point: Heating needed below this temperature
    :type winter_balance_point: int
    :param heating_base_use_per_day: The total base heating use per day
    :type heating_base_use_per_day: float
    :param heating_weather_factor: The heating weather factor
    :type heating_weather_factor: float
    :param is_cooling_weather_sensitive: Is cooling weather sensitive?
    :type is_cooling_weather_sensitive: bool
    :param summer_balance_point: Cooling needed above this temperature
    :type summer_balance_point: int
    :param cooling_base_use_per_day: The total base cooling use per day
    :type cooling_base_use_per_day: float
    :param cooling_weather_factor: The cooling weather factor
    :type cooling_weather_factor: float
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'int'},
        'is_heating_weather_sensitive': {'key': 'isHeatingWeatherSensitive', 'type': 'bool'},
        'winter_balance_point': {'key': 'winterBalancePoint', 'type': 'int'},
        'heating_base_use_per_day': {'key': 'heatingBaseUsePerDay', 'type': 'float'},
        'heating_weather_factor': {'key': 'heatingWeatherFactor', 'type': 'float'},
        'is_cooling_weather_sensitive': {'key': 'isCoolingWeatherSensitive', 'type': 'bool'},
        'summer_balance_point': {'key': 'summerBalancePoint', 'type': 'int'},
        'cooling_base_use_per_day': {'key': 'coolingBaseUsePerDay', 'type': 'float'},
        'cooling_weather_factor': {'key': 'coolingWeatherFactor', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
    }

    def __init__(self, year=None, is_heating_weather_sensitive=None, winter_balance_point=None, heating_base_use_per_day=None, heating_weather_factor=None, is_cooling_weather_sensitive=None, summer_balance_point=None, cooling_base_use_per_day=None, cooling_weather_factor=None, use_unit=None):
        super(MeterCalendarizedUseVsWeatherResponse, self).__init__()
        self.year = year
        self.is_heating_weather_sensitive = is_heating_weather_sensitive
        self.winter_balance_point = winter_balance_point
        self.heating_base_use_per_day = heating_base_use_per_day
        self.heating_weather_factor = heating_weather_factor
        self.is_cooling_weather_sensitive = is_cooling_weather_sensitive
        self.summer_balance_point = summer_balance_point
        self.cooling_base_use_per_day = cooling_base_use_per_day
        self.cooling_weather_factor = cooling_weather_factor
        self.use_unit = use_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupMember(Model):
    """PlaceGroupMember.

    :param place_group_id: The place group this place will belong to <span
     class='property-internal'>Required (defined)</span>
    :type place_group_id: int
    :param include_in_charts: Whether to include this place in the group's
     benchmark charts <span class='property-internal'>Required (defined)</span>
    :type include_in_charts: bool
    """

    _attribute_map = {
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, place_group_id=None, include_in_charts=None):
        super(PlaceGroupMember, self).__init__()
        self.place_group_id = place_group_id
        self.include_in_charts = include_in_charts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillViewVendorChild(Model):
    """BillViewVendorChild.

    :param vendor_id: The vendor identifier
    :type vendor_id: int
    :param vendor_code: The vendor code
    :type vendor_code: str
    :param vendor_info: The vendor info
    :type vendor_info: str
    :param address:
    :type address: ~energycap.sdk.models.BillViewAddressChild
    """

    _attribute_map = {
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'BillViewAddressChild'},
    }

    def __init__(self, vendor_id=None, vendor_code=None, vendor_info=None, address=None):
        super(BillViewVendorChild, self).__init__()
        self.vendor_id = vendor_id
        self.vendor_code = vendor_code
        self.vendor_info = vendor_info
        self.address = address



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDetailsResponse(Model):
    """Response object containing all the details related to calculated bill setup
    for a meter. Includes use, cost, meter line items, and account line items.

    :param version:
    :type version: ~energycap.sdk.models.DistributionVersionResponse
    :param use:
    :type use: ~energycap.sdk.models.CalculatedBillUseResponse
    :param cost:
    :type cost: ~energycap.sdk.models.CalculatedBillCostResponse
    :param demand:
    :type demand: ~energycap.sdk.models.CalculatedBillDemandResponse
    :param meter_line_items: Additional meter bodylines to be added to the
     bill
     The line items are returned in the correct display order
    :type meter_line_items:
     list[~energycap.sdk.models.GenericBodylineResponse]
    :param account_line_items: Additional account bodylines to be added to the
     bill
     The line items are returned in the correct display order
    :type account_line_items:
     list[~energycap.sdk.models.GenericBodylineResponse]
    """

    _attribute_map = {
        'version': {'key': 'version', 'type': 'DistributionVersionResponse'},
        'use': {'key': 'use', 'type': 'CalculatedBillUseResponse'},
        'cost': {'key': 'cost', 'type': 'CalculatedBillCostResponse'},
        'demand': {'key': 'demand', 'type': 'CalculatedBillDemandResponse'},
        'meter_line_items': {'key': 'meterLineItems', 'type': '[GenericBodylineResponse]'},
        'account_line_items': {'key': 'accountLineItems', 'type': '[GenericBodylineResponse]'},
    }

    def __init__(self, version=None, use=None, cost=None, demand=None, meter_line_items=None, account_line_items=None):
        super(CalculatedBillDetailsResponse, self).__init__()
        self.version = version
        self.use = use
        self.cost = cost
        self.demand = demand
        self.meter_line_items = meter_line_items
        self.account_line_items = account_line_items



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFUpdate(Model):
    """UDFUpdate.

    :param udf_id: The Udf's ID. When creating a new UDF, assign null to this
     property. <span class='property-internal'>Required (defined)</span>
    :type udf_id: int
    :param name: The UDF's name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type name: str
    :param data_type_id: The UDF's data type identifier. Possible value
     include 1 (boolean), 2 (integer), 3 (string), 4 (double), 6 (date), 12
     (select list) and 13 (url) <span class='property-internal'>Required</span>
    :type data_type_id: int
    :param udf_select_values: <p>An array of options to populate a UDF select
     list.</p>
     <p>Required when the UDF being edited has a dataTypeId of 12 otherwise
     this will be ignored.</p>
     <p>To remove an option from the select list, omit it from this array.
     Options that are in use may not be deleted. To add a new option, pass in
     null as the udfSelectValueId</p> <span class='property-internal'>Required
     when dataTypeId is set to 12</span>
    :type udf_select_values: list[~energycap.sdk.models.UDFSelectValueUpdate]
    """

    _validation = {
        'udf_id': {'required': True},
        'name': {'required': True, 'max_length': 32, 'min_length': 0},
        'data_type_id': {'required': True},
    }

    _attribute_map = {
        'udf_id': {'key': 'udfId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
        'udf_select_values': {'key': 'udfSelectValues', 'type': '[UDFSelectValueUpdate]'},
    }

    def __init__(self, udf_id, name, data_type_id, udf_select_values=None):
        super(UDFUpdate, self).__init__()
        self.udf_id = udf_id
        self.name = name
        self.data_type_id = data_type_id
        self.udf_select_values = udf_select_values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BodylineChild(Model):
    """BodylineChild.

    :param body_line_id: The bodyline identifier
    :type body_line_id: int
    :param account_id: The account identifier
    :type account_id: int
    :param meter_id: The meter identifier
    :type meter_id: int
    :param display_order: The display order
    :type display_order: int
    :param caption: The caption
    :type caption: str
    :param value: The bodyline's value
    :type value: float
    :param value_is_info_only:
    :type value_is_info_only: bool
    :param cost: The cost attributed to the bodyline
    :type cost: float
    :param cost_is_info_only: Is the cost value counted towards the overall
     total cost or info only
    :type cost_is_info_only: bool
    :param value_unit:
    :type value_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param general_ledger:
    :type general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    """

    _attribute_map = {
        'body_line_id': {'key': 'bodyLineId', 'type': 'int'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
        'value_is_info_only': {'key': 'valueIsInfoOnly', 'type': 'bool'},
        'cost': {'key': 'cost', 'type': 'float'},
        'cost_is_info_only': {'key': 'costIsInfoOnly', 'type': 'bool'},
        'value_unit': {'key': 'valueUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'general_ledger': {'key': 'generalLedger', 'type': 'GeneralLedgerChild'},
    }

    def __init__(self, body_line_id=None, account_id=None, meter_id=None, display_order=None, caption=None, value=None, value_is_info_only=None, cost=None, cost_is_info_only=None, value_unit=None, cost_unit=None, observation_type=None, general_ledger=None):
        super(BodylineChild, self).__init__()
        self.body_line_id = body_line_id
        self.account_id = account_id
        self.meter_id = meter_id
        self.display_order = display_order
        self.caption = caption
        self.value = value
        self.value_is_info_only = value_is_info_only
        self.cost = cost
        self.cost_is_info_only = cost_is_info_only
        self.value_unit = value_unit
        self.cost_unit = cost_unit
        self.observation_type = observation_type
        self.general_ledger = general_ledger



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestSavingsYearlyResponse(Model):
    """MeterDigestSavingsYearlyResponse.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_cap:
    :type meter_cap: ~energycap.sdk.models.MeterCAPResponse
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param all_time_batcc_native_use: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Native Use
    :type all_time_batcc_native_use: float
    :param all_time_native_use: Program to Date Native Use
    :type all_time_native_use: float
    :param all_time_savings_native_use: Program to Date Savings Native Use =
     allTimeBATCCNativeUse - allTimeNativeUse
    :type all_time_savings_native_use: float
    :param all_time_batcc_common_use: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Common Use
    :type all_time_batcc_common_use: float
    :param all_time_common_use: Program to Date Common Use
    :type all_time_common_use: float
    :param all_time_savings_common_use: Program to Date Savings Common Use =
     allTimeBATCCCommonUse - allTimeCommonUse
    :type all_time_savings_common_use: float
    :param all_time_batcc_total_cost: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Total Cost
    :type all_time_batcc_total_cost: float
    :param all_time_total_cost: Program to Date Total Cost
    :type all_time_total_cost: float
    :param all_time_savings_total_cost: Program to Date Savings Total Cost =
     allTimeBATCCTotalCost - allTimeTotalCost
    :type all_time_savings_total_cost: float
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param savings_start_date: The saving program's start date
    :type savings_start_date: datetime
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.MeterDigestSavingsYearlyResponseResults]
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_cap': {'key': 'meterCAP', 'type': 'MeterCAPResponse'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'all_time_batcc_native_use': {'key': 'allTimeBATCCNativeUse', 'type': 'float'},
        'all_time_native_use': {'key': 'allTimeNativeUse', 'type': 'float'},
        'all_time_savings_native_use': {'key': 'allTimeSavingsNativeUse', 'type': 'float'},
        'all_time_batcc_common_use': {'key': 'allTimeBATCCCommonUse', 'type': 'float'},
        'all_time_common_use': {'key': 'allTimeCommonUse', 'type': 'float'},
        'all_time_savings_common_use': {'key': 'allTimeSavingsCommonUse', 'type': 'float'},
        'all_time_batcc_total_cost': {'key': 'allTimeBATCCTotalCost', 'type': 'float'},
        'all_time_total_cost': {'key': 'allTimeTotalCost', 'type': 'float'},
        'all_time_savings_total_cost': {'key': 'allTimeSavingsTotalCost', 'type': 'float'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'savings_start_date': {'key': 'savingsStartDate', 'type': 'iso-8601'},
        'results': {'key': 'results', 'type': '[MeterDigestSavingsYearlyResponseResults]'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, meter_cap=None, native_use_unit=None, common_use_unit=None, cost_unit=None, all_time_batcc_native_use=None, all_time_native_use=None, all_time_savings_native_use=None, all_time_batcc_common_use=None, all_time_common_use=None, all_time_savings_common_use=None, all_time_batcc_total_cost=None, all_time_total_cost=None, all_time_savings_total_cost=None, updated=None, savings_start_date=None, results=None):
        super(MeterDigestSavingsYearlyResponse, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_cap = meter_cap
        self.native_use_unit = native_use_unit
        self.common_use_unit = common_use_unit
        self.cost_unit = cost_unit
        self.all_time_batcc_native_use = all_time_batcc_native_use
        self.all_time_native_use = all_time_native_use
        self.all_time_savings_native_use = all_time_savings_native_use
        self.all_time_batcc_common_use = all_time_batcc_common_use
        self.all_time_common_use = all_time_common_use
        self.all_time_savings_common_use = all_time_savings_common_use
        self.all_time_batcc_total_cost = all_time_batcc_total_cost
        self.all_time_total_cost = all_time_total_cost
        self.all_time_savings_total_cost = all_time_savings_total_cost
        self.updated = updated
        self.savings_start_date = savings_start_date
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarRatingChild(Model):
    """EnergyStarRatingChild.

    :param rating_date:
    :type rating_date: datetime
    :param rating:
    :type rating: int
    """

    _attribute_map = {
        'rating_date': {'key': 'ratingDate', 'type': 'iso-8601'},
        'rating': {'key': 'rating', 'type': 'int'},
    }

    def __init__(self, rating_date=None, rating=None):
        super(EnergyStarRatingChild, self).__init__()
        self.rating_date = rating_date
        self.rating = rating



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseGHGType(Model):
    """PlaceDigestGHGMonthlyResponseGHGType.

    :param ghg_type_id: GHG type identifier
    :type ghg_type_id: int
    :param ghg_type_code: GHG type code
    :type ghg_type_code: str
    :param ghg_type_info: GHG type info
    :type ghg_type_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGMonthlyResponseTargetComparison
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGMonthlyResponseResults]
    """

    _attribute_map = {
        'ghg_type_id': {'key': 'ghgTypeId', 'type': 'int'},
        'ghg_type_code': {'key': 'ghgTypeCode', 'type': 'str'},
        'ghg_type_info': {'key': 'ghgTypeInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGMonthlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGMonthlyResponseResults]'},
    }

    def __init__(self, ghg_type_id=None, ghg_type_code=None, ghg_type_info=None, target_comparison=None, results=None):
        super(PlaceDigestGHGMonthlyResponseGHGType, self).__init__()
        self.ghg_type_id = ghg_type_id
        self.ghg_type_code = ghg_type_code
        self.ghg_type_info = ghg_type_info
        self.target_comparison = target_comparison
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OkResult(Model):
    """OkResult.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar status_code:
    :vartype status_code: int
    """

    _validation = {
        'status_code': {'readonly': True},
    }

    _attribute_map = {
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self):
        super(OkResult, self).__init__()
        self.status_code = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PostalCodeResponse(Model):
    """PostalCodeResponse.

    :param postal_code: The postal code
    :type postal_code: str
    :param city: The city of the postal code
    :type city: str
    :param state: The state of the postal code
    :type state: str
    :param country: The country of the postal code
    :type country: str
    :param weather_station:
    :type weather_station:
     ~energycap.sdk.models.PostalCodeResponseWeatherStation
    """

    _attribute_map = {
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'weather_station': {'key': 'weatherStation', 'type': 'PostalCodeResponseWeatherStation'},
    }

    def __init__(self, postal_code=None, city=None, state=None, country=None, weather_station=None):
        super(PostalCodeResponse, self).__init__()
        self.postal_code = postal_code
        self.city = city
        self.state = state
        self.country = country
        self.weather_station = weather_station



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestSavingsMonthlyResponse(Model):
    """MeterDigestSavingsMonthlyResponse.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_cap:
    :type meter_cap: ~energycap.sdk.models.MeterCAPResponse
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.MeterDigestSavingsMonthlyResponseResults]
    :param updated: The date and time the data was updated
    :type updated: datetime
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_cap': {'key': 'meterCAP', 'type': 'MeterCAPResponse'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'results': {'key': 'results', 'type': '[MeterDigestSavingsMonthlyResponseResults]'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, meter_cap=None, native_use_unit=None, common_use_unit=None, cost_unit=None, results=None, updated=None):
        super(MeterDigestSavingsMonthlyResponse, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_cap = meter_cap
        self.native_use_unit = native_use_unit
        self.common_use_unit = common_use_unit
        self.cost_unit = cost_unit
        self.results = results
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchPlaceChild(Model):
    """SearchPlaceChild.

    :param result:
    :type result: ~energycap.sdk.models.SearchPlaceChildSearchPlaceChild
    """

    _attribute_map = {
        'result': {'key': 'result', 'type': 'SearchPlaceChildSearchPlaceChild'},
    }

    def __init__(self, result=None):
        super(SearchPlaceChild, self).__init__()
        self.result = result



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DeviceChannelChild(Model):
    """DeviceChannelChild.

    :param last_calibrated: The date and time the channel was last calibrated
    :type last_calibrated: datetime
    :param channel_number: The channel number
    :type channel_number: int
    :param channel_text: The channel text
    :type channel_text: str
    :param channel_flag: The channel flag
    :type channel_flag: bool
    :param channel_integer: The channel integer
    :type channel_integer: int
    :param channel_float: The channel float
    :type channel_float: float
    :param channel_char: The channel char
    :type channel_char: str
    :param read_direction: The channel's read direction
    :type read_direction: str
    :param read_method: The channel's read method
    :type read_method: str
    :param rf_ert_id:
    :type rf_ert_id: str
    :param rf_ert_type:
    :type rf_ert_type: int
    :param rf_frequency:
    :type rf_frequency: float
    :param rf_tone:
    :type rf_tone: float
    :param decode_type: The decode type of the channel
    :type decode_type: int
    """

    _attribute_map = {
        'last_calibrated': {'key': 'lastCalibrated', 'type': 'iso-8601'},
        'channel_number': {'key': 'channelNumber', 'type': 'int'},
        'channel_text': {'key': 'channelText', 'type': 'str'},
        'channel_flag': {'key': 'channelFlag', 'type': 'bool'},
        'channel_integer': {'key': 'channelInteger', 'type': 'int'},
        'channel_float': {'key': 'channelFloat', 'type': 'float'},
        'channel_char': {'key': 'channelChar', 'type': 'str'},
        'read_direction': {'key': 'readDirection', 'type': 'str'},
        'read_method': {'key': 'readMethod', 'type': 'str'},
        'rf_ert_id': {'key': 'rf_Ert_Id', 'type': 'str'},
        'rf_ert_type': {'key': 'rf_Ert_Type', 'type': 'int'},
        'rf_frequency': {'key': 'rf_Frequency', 'type': 'float'},
        'rf_tone': {'key': 'rf_Tone', 'type': 'float'},
        'decode_type': {'key': 'decodeType', 'type': 'int'},
    }

    def __init__(self, last_calibrated=None, channel_number=None, channel_text=None, channel_flag=None, channel_integer=None, channel_float=None, channel_char=None, read_direction=None, read_method=None, rf_ert_id=None, rf_ert_type=None, rf_frequency=None, rf_tone=None, decode_type=None):
        super(DeviceChannelChild, self).__init__()
        self.last_calibrated = last_calibrated
        self.channel_number = channel_number
        self.channel_text = channel_text
        self.channel_flag = channel_flag
        self.channel_integer = channel_integer
        self.channel_float = channel_float
        self.channel_char = channel_char
        self.read_direction = read_direction
        self.read_method = read_method
        self.rf_ert_id = rf_ert_id
        self.rf_ert_type = rf_ert_type
        self.rf_frequency = rf_frequency
        self.rf_tone = rf_tone
        self.decode_type = decode_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceCreate(Model):
    """PlaceCreate.

    :param place_code: The place code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type place_code: str
    :param place_info: The place info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type place_info: str
    :param parent_place_id: The identifier for the parent of the place. The
     parent is the place directly above the current place on the buildings and
     meters tree <span class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Place)</span>
    :type parent_place_id: int
    :param place_type_id: The identifier for the place type <span
     class='property-internal'>Required</span>
    :type place_type_id: int
    :param primary_use_id: The identifier for the place's primary use
    :type primary_use_id: int
    :param build_date: The date and time the place was built
    :type build_date: datetime
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param weather_station_code: The code for the weather station the place is
     assigned to <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type weather_station_code: str
    """

    _validation = {
        'place_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'place_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'parent_place_id': {'required': True},
        'place_type_id': {'required': True},
        'weather_station_code': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'parent_place_id': {'key': 'parentPlaceId', 'type': 'int'},
        'place_type_id': {'key': 'placeTypeId', 'type': 'int'},
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'build_date': {'key': 'buildDate', 'type': 'iso-8601'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
    }

    def __init__(self, place_code, place_info, parent_place_id, place_type_id, primary_use_id=None, build_date=None, address=None, weather_station_code=None):
        super(PlaceCreate, self).__init__()
        self.place_code = place_code
        self.place_info = place_info
        self.parent_place_id = parent_place_id
        self.place_type_id = place_type_id
        self.primary_use_id = primary_use_id
        self.build_date = build_date
        self.address = address
        self.weather_station_code = weather_station_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceCategoryResponse(Model):
    """PlaceCategoryResponse.

    :param place_group_category_id: The place category identifier
    :type place_group_category_id: int
    :param place_group_category_code: The place category code
    :type place_group_category_code: str
    :param place_group_category_info: The place category name
    :type place_group_category_info: str
    :param auto_group: Is this category an automatically maintained one?
    :type auto_group: bool
    :param number_of_groups: Number of groups within this category
    :type number_of_groups: int
    :param number_of_groups_with_visible_members: Number of groups within this
     category with members the logged in can see
    :type number_of_groups_with_visible_members: int
    """

    _attribute_map = {
        'place_group_category_id': {'key': 'placeGroupCategoryId', 'type': 'int'},
        'place_group_category_code': {'key': 'placeGroupCategoryCode', 'type': 'str'},
        'place_group_category_info': {'key': 'placeGroupCategoryInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'number_of_groups': {'key': 'numberOfGroups', 'type': 'int'},
        'number_of_groups_with_visible_members': {'key': 'numberOfGroupsWithVisibleMembers', 'type': 'int'},
    }

    def __init__(self, place_group_category_id=None, place_group_category_code=None, place_group_category_info=None, auto_group=None, number_of_groups=None, number_of_groups_with_visible_members=None):
        super(PlaceCategoryResponse, self).__init__()
        self.place_group_category_id = place_group_category_id
        self.place_group_category_code = place_group_category_code
        self.place_group_category_info = place_group_category_info
        self.auto_group = auto_group
        self.number_of_groups = number_of_groups
        self.number_of_groups_with_visible_members = number_of_groups_with_visible_members



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackTaskVersionResponse(Model):
    """ChargebackTaskVersionResponse.

    :param version_id: The specific version id within the task we are
     reporting on
    :type version_id: int
    :param number_of_bills_created: The number of bills created for this
     version within the task
    :type number_of_bills_created: int
    :param error_message: Error that may have occurred when running this
     version within the task
    :type error_message: str
    :param destination_bill_ids: The billids of all the destination bills
     created by this version within the task
    :type destination_bill_ids: list[int]
    :param source_bill_id: If this was a bill split task, then ID of the bill
     that was split by this version within the task
    :type source_bill_id: int
    :param task_id: Identifier for the task
    :type task_id: int
    :param workflow:
    :type workflow: ~energycap.sdk.models.ChargebackWorkflowStepChild
    :param task_begin: Begin date when the task started
    :type task_begin: datetime
    :param task_end: End date when the task ended
    :type task_end: datetime
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param billing_period: The billing period the task was run for
    :type billing_period: int
    :param batch:
    :type batch: ~energycap.sdk.models.BatchChild
    :param settings: The task's settings
    :type settings: object
    :param comment: User comments on the task
    :type comment: str
    :param status: Current status of the task
    :type status: str
    :param chargeback_type: The chargeback type.  Either "Split" or
     "Calculation"
    :type chargeback_type: str
    :param reversed_by:
    :type reversed_by: ~energycap.sdk.models.UserChild
    :param reversed_date: The date when all bills generated by the task were
     voided or deleted
    :type reversed_date: datetime
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'number_of_bills_created': {'key': 'numberOfBillsCreated', 'type': 'int'},
        'error_message': {'key': 'errorMessage', 'type': 'str'},
        'destination_bill_ids': {'key': 'destinationBillIds', 'type': '[int]'},
        'source_bill_id': {'key': 'sourceBillId', 'type': 'int'},
        'task_id': {'key': 'taskId', 'type': 'int'},
        'workflow': {'key': 'workflow', 'type': 'ChargebackWorkflowStepChild'},
        'task_begin': {'key': 'taskBegin', 'type': 'iso-8601'},
        'task_end': {'key': 'taskEnd', 'type': 'iso-8601'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'batch': {'key': 'batch', 'type': 'BatchChild'},
        'settings': {'key': 'settings', 'type': 'object'},
        'comment': {'key': 'comment', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'chargeback_type': {'key': 'chargebackType', 'type': 'str'},
        'reversed_by': {'key': 'reversedBy', 'type': 'UserChild'},
        'reversed_date': {'key': 'reversedDate', 'type': 'iso-8601'},
    }

    def __init__(self, version_id=None, number_of_bills_created=None, error_message=None, destination_bill_ids=None, source_bill_id=None, task_id=None, workflow=None, task_begin=None, task_end=None, user=None, billing_period=None, batch=None, settings=None, comment=None, status=None, chargeback_type=None, reversed_by=None, reversed_date=None):
        super(ChargebackTaskVersionResponse, self).__init__()
        self.version_id = version_id
        self.number_of_bills_created = number_of_bills_created
        self.error_message = error_message
        self.destination_bill_ids = destination_bill_ids
        self.source_bill_id = source_bill_id
        self.task_id = task_id
        self.workflow = workflow
        self.task_begin = task_begin
        self.task_end = task_end
        self.user = user
        self.billing_period = billing_period
        self.batch = batch
        self.settings = settings
        self.comment = comment
        self.status = status
        self.chargeback_type = chargeback_type
        self.reversed_by = reversed_by
        self.reversed_date = reversed_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OtherSavingsCategory(Model):
    """OtherSavingsCategory.

    :param other_savings_category_id: Other savings category identifier
    :type other_savings_category_id: int
    :param other_savings_category_info: Other savings category name
    :type other_savings_category_info: str
    """

    _attribute_map = {
        'other_savings_category_id': {'key': 'otherSavingsCategoryId', 'type': 'int'},
        'other_savings_category_info': {'key': 'otherSavingsCategoryInfo', 'type': 'str'},
    }

    def __init__(self, other_savings_category_id=None, other_savings_category_info=None):
        super(OtherSavingsCategory, self).__init__()
        self.other_savings_category_id = other_savings_category_id
        self.other_savings_category_info = other_savings_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificWidgetResponse(Model):
    """SpecificWidgetResponse.

    :param specific_widget_id: Specific widget identifier
    :type specific_widget_id: int
    :param title: Widget title
    :type title: str
    :param widget_info: Widget title
    :type widget_info: str
    :param description: Widget description
    :type description: str
    :param row: Dashboard row
    :type row: int
    :param col: Dashboard column
    :type col: int
    :param height: Widget height
    :type height: int
    :param width: Widget width
    :type width: int
    :param filters: Widget filters
    :type filters: list[~energycap.sdk.models.FilterResponse]
    """

    _attribute_map = {
        'specific_widget_id': {'key': 'specificWidgetId', 'type': 'int'},
        'title': {'key': 'title', 'type': 'str'},
        'widget_info': {'key': 'widgetInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'row': {'key': 'row', 'type': 'int'},
        'col': {'key': 'col', 'type': 'int'},
        'height': {'key': 'height', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'filters': {'key': 'filters', 'type': '[FilterResponse]'},
    }

    def __init__(self, specific_widget_id=None, title=None, widget_info=None, description=None, row=None, col=None, height=None, width=None, filters=None):
        super(SpecificWidgetResponse, self).__init__()
        self.specific_widget_id = specific_widget_id
        self.title = title
        self.widget_info = widget_info
        self.description = description
        self.row = row
        self.col = col
        self.height = height
        self.width = width
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApprovalWorkflowChild(Model):
    """ApprovalWorkflowChild.

    :param approval_mode_enabled:
    :type approval_mode_enabled: bool
    :param confirm_edit_delete:
    :type confirm_edit_delete: bool
    """

    _attribute_map = {
        'approval_mode_enabled': {'key': 'approvalModeEnabled', 'type': 'bool'},
        'confirm_edit_delete': {'key': 'confirmEditDelete', 'type': 'bool'},
    }

    def __init__(self, approval_mode_enabled=None, confirm_edit_delete=None):
        super(ApprovalWorkflowChild, self).__init__()
        self.approval_mode_enabled = approval_mode_enabled
        self.confirm_edit_delete = confirm_edit_delete



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountRateChild(Model):
    """AccountRateChild.

    :param rate:
    :type rate: ~energycap.sdk.models.RateChild
    :param start_date:
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _attribute_map = {
        'rate': {'key': 'rate', 'type': 'RateChild'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, rate=None, start_date=None, end_date=None):
        super(AccountRateChild, self).__init__()
        self.rate = rate
        self.start_date = start_date
        self.end_date = end_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillViewMeterChild(Model):
    """BillViewMeterChild.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_type:
    :type meter_type: ~energycap.sdk.models.MeterTypeChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param serial_number: The meter's serial number
    :type serial_number: str
    :param rate:
    :type rate: ~energycap.sdk.models.RateChild
    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param general_ledger:
    :type general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_type': {'key': 'meterType', 'type': 'MeterTypeChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'serial_number': {'key': 'serialNumber', 'type': 'str'},
        'rate': {'key': 'rate', 'type': 'RateChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'general_ledger': {'key': 'generalLedger', 'type': 'GeneralLedgerChild'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, meter_type=None, commodity=None, serial_number=None, rate=None, place=None, general_ledger=None):
        super(BillViewMeterChild, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_type = meter_type
        self.commodity = commodity
        self.serial_number = serial_number
        self.rate = rate
        self.place = place
        self.general_ledger = general_ledger



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponse(Model):
    """PlaceDigestGHGYearlyResponse.

    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_id: The place identifier
    :type place_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param equivalent_co2_emissions_unit:
    :type equivalent_co2_emissions_unit: ~energycap.sdk.models.UnitChild
    :param ghg_types: List of greenhouse gas types with use by year
    :type ghg_types:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseGHGType]
    :param ghg_scopes: List of greenhouse gas scopes by type with use by year
    :type ghg_scopes:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseGHGScope]
    """

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'equivalent_co2_emissions_unit': {'key': 'equivalentCO2EmissionsUnit', 'type': 'UnitChild'},
        'ghg_types': {'key': 'ghgTypes', 'type': '[PlaceDigestGHGYearlyResponseGHGType]'},
        'ghg_scopes': {'key': 'ghgScopes', 'type': '[PlaceDigestGHGYearlyResponseGHGScope]'},
    }

    def __init__(self, place_code=None, place_info=None, place_id=None, updated=None, equivalent_co2_emissions_unit=None, ghg_types=None, ghg_scopes=None):
        super(PlaceDigestGHGYearlyResponse, self).__init__()
        self.place_code = place_code
        self.place_info = place_info
        self.place_id = place_id
        self.updated = updated
        self.equivalent_co2_emissions_unit = equivalent_co2_emissions_unit
        self.ghg_types = ghg_types
        self.ghg_scopes = ghg_scopes



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagWidget(Model):
    """FlagWidget.

    :param view_by: The type of entity we are grouping bill flags by - Meter,
     Account or Building
    :type view_by: str
    :param flag_status: The status of bill flags - Unresolved or Resolved
    :type flag_status: str
    :param total_cost: Total cost for all the bills that are represented by
     the bill flags
    :type total_cost: float
    :param total_cost_recovery: Total cost recovery represented by the bill
     flags
    :type total_cost_recovery: float
    :param flag_count: Total number of bill flags represented
    :type flag_count: int
    :param results: List of bill flag rows
     The rows are sorted by highest cost , then by highest cost recovery, and
     then by the item's display alphabetically
    :type results: list[~energycap.sdk.models.FlagWidgetChild]
    :param total_number_of_results: Total number of results available
     If pagination was applied, Results list will have "pagesize" out of
     TotalNumberOfResults
     If pagination was not applied, Results list will have 100 out of
     TotalNumberOfResults
    :type total_number_of_results: int
    """

    _attribute_map = {
        'view_by': {'key': 'viewBy', 'type': 'str'},
        'flag_status': {'key': 'flagStatus', 'type': 'str'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'total_cost_recovery': {'key': 'totalCostRecovery', 'type': 'float'},
        'flag_count': {'key': 'flagCount', 'type': 'int'},
        'results': {'key': 'results', 'type': '[FlagWidgetChild]'},
        'total_number_of_results': {'key': 'totalNumberOfResults', 'type': 'int'},
    }

    def __init__(self, view_by=None, flag_status=None, total_cost=None, total_cost_recovery=None, flag_count=None, results=None, total_number_of_results=None):
        super(FlagWidget, self).__init__()
        self.view_by = view_by
        self.flag_status = flag_status
        self.total_cost = total_cost
        self.total_cost_recovery = total_cost_recovery
        self.flag_count = flag_count
        self.results = results
        self.total_number_of_results = total_number_of_results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillContainsLineItemDescriptionsSetting(Model):
    """BillContainsLineItemDescriptionsSetting.

    :param line_item_descriptions: List of line item descriptions. Each
     description must be shorter than 32 characters.
     If SettingStatus is set to Skip and no value is provided, EnergyCAP
     default will be set <span class='property-internal'>Required when
     SettingStatus is set to Check, or Hold</span><span
     class='property-internal'>List cannot be empty</span>
    :type line_item_descriptions: list[str]
    :param setting_status: The status of the audit setting <span
     class='property-internal'>One of Check, Hold, Skip </span>
    :type setting_status: str
    :param setting_code: The setting code. Not used when updating settings.
    :type setting_code: str
    :param setting_description: A description of the setting. Not used when
     updating settings
    :type setting_description: str
    """

    _attribute_map = {
        'line_item_descriptions': {'key': 'lineItemDescriptions', 'type': '[str]'},
        'setting_status': {'key': 'settingStatus', 'type': 'str'},
        'setting_code': {'key': 'settingCode', 'type': 'str'},
        'setting_description': {'key': 'settingDescription', 'type': 'str'},
    }

    def __init__(self, line_item_descriptions=None, setting_status=None, setting_code=None, setting_description=None):
        super(BillContainsLineItemDescriptionsSetting, self).__init__()
        self.line_item_descriptions = line_item_descriptions
        self.setting_status = setting_status
        self.setting_code = setting_code
        self.setting_description = setting_description
